@@ -1,18 +1,16 @@
 import random
 import time
-
 from colorama import Fore
-
 from progress_table import ProgressTable
 
 progress = ProgressTable(columns=["step", "x", "x squared"])
 progress.add_column("x root", color=Fore.RED)
 
 for step in range(20):
-    progress["step"] = step
+    progress["step"] = step  # insert step value in the current row
 
-    for _ in progress(range(10), length=5):
-        time.sleep(0.1)  # artificial work
+    for _ in progress(range(10)):  # display progress bar
+        time.sleep(0.1)  # simulate artificial work
 
     x = random.randint(0, 200)
     progress["x"] = x
@@ -21,3 +19,8 @@ for step in range(20):
     progress.next_row()
 
 progress.close()
+
+# export your data
+data = progress.to_list()
+pandas_df = progress.to_df()
+np_array = progress.to_numpy()
\ No newline at end of file
